@@ -19,7 +19,7 @@ use base qw( Exporter );
 our @EXPORT = qw( alien_ok run_ok xs_ok ffi_ok with_subtest synthetic helper_ok interpolate_template_is );
 
 # ABSTRACT: Testing tools for Alien modules
-our $VERSION = '0.71_01'; # TRIAL VERSION
+our $VERSION = '0.72_01'; # TRIAL VERSION
 $VERSION = eval $VERSION;
 
 
@@ -134,6 +134,18 @@ sub _flags
     : $class->$method;
 }
 
+{
+  my $seen = 0;
+  sub _warn_cpp
+  {
+    return if $seen;
+    my $ctx = context();
+    $ctx->diag("Test::Alien xs_ok C++ is considered experimental");
+    $ctx->release;
+    $seen++;
+  }
+}
+
 sub xs_ok
 {
   my $cb;
@@ -163,6 +175,7 @@ sub xs_ok
 
   if($xs->{cpp} || $xs->{'C++'})
   {
+    _warn_cpp();
     $xs->{pxs}->{'C++'} = 1;
     $xs->{cbuilder_compile}->{'C++'} = 1;
   }
@@ -564,7 +577,7 @@ Test::Alien - Testing tools for Alien modules
 
 =head1 VERSION
 
-version 0.71_01
+version 0.72_01
 
 =head1 SYNOPSIS
 
@@ -787,6 +800,8 @@ Spew copious debug information via test note.
 
 =item C++ or cpp
 
+[EXPERIMENTAL]
+
 XS should be compiled as C++.
 
 =back
